import Vue from 'vue'
import Vuex from 'vuex'
import axios from 'axios'
import inventory from "./modules/inventory"
import products from "./modules/products"
import user from "./modules/user"
import reviews from "./modules/reviews"
import search from "./modules/search"
import category from "./modules/category"

Vue.use(Vuex)

export default new Vuex.Store({

  modules:{
    inventory,
    products,
    user,
    reviews,
    search,
    category
  },

  state: {
    orderConfirmed: false
  },


  getters: {

  },


  actions: {
    confirmOrder({commit}) {
      commit('CONFIRM_ORDER')
    },

    resetConfirmation({commit}) {
      commit('RESET_CONFIRMATION')
    }
  },

  mutations: {

    RESET_CONFIRMATION (state) {
      state.orderConfirmed = false
    },

    CONFIRM_ORDER (state) {

      // loop through every item in cart
      for( let i = 0; i < state.products.cart.length; i++){

        //make JSON object from that order
        let order = {
          "orderDate": new Date(Date.now()).toISOString(),
          "customer": {},
          "product": {},
          "warehouse": {},
          "quantity": state.products.cart[i].quantity,
          "totalPrice": state.products.cart[i].quantity * state.products.cart[i].product.price
        };

        console.log(order)

        let userId = state.user.user.id;
        let productId = state.products.cart[i].product.id
        let warehouse = state.products.cart[i].warehouse

        // post to warehouse the order details in the JSON object
        axios.post('http://localhost:8090/customers/'+ userId +'/orders/'+ productId +'/warehouse/'+warehouse, order)
            .then(response => console.log(response));

        // reduce quantity in the warehouse the product was bought from
        axios.get('http://localhost:809'+ warehouse + '/inventory/purchase?product_id=' + productId + '&qty=' + order.quantity)
            .then(response => console.log(response))

      }

      products.mutations.EMPTY_CART(state.products)
      state.orderConfirmed = true
    }
  },

})
