import axios from "axios";
export default {

    // VUEX store script for handling the products and cart object
    // in the store

    state: {
        products: [],
        cart: [],
        product: {}
    },

    getters: {
        getAllProducts: state => {
            return state.products
        },

        getProduct: state => {
            return state.product
        },

        filterProductById: (state) => (id) => {
            return state.products.find(product => product.id === id)
        },

        // NEW
        cartItemCount (state) {
            return state.cart.length
        },

        // NEW
        cartTotalPrice (state) {
            let total = 0;

            for(let i = 0; i < state.cart.length; i++) {
                total += state.cart[i].product.price * state.cart[i].quantity;
            }

            return total.toFixed(2);
        },
    },


    actions: {
        setProductById({commit}, id){
            axios.get('http://localhost:8090/product?id='+ id)
                .then(response => {commit('setProductById', response.data)})
        },

        // NEW
        getProducts({commit}){
            axios.get('http://localhost:8090/products')
                .then(response => {commit('GET_PRODUCTS', response.data)})
        },

        addProductToCart({commit}, {product, quantity, warehouse}) {
            commit('ADD_TO_CART', {product, quantity, warehouse})
        },

        removeProductFromCart({commit}, product) {
            commit('REMOVE_PRODUCT_FROM_CART', product)
        },

        increase({commit}, item) {
            commit('INCREASE', item)
        },

        decrease({commit}, item) {
            commit('DECREASE', item)
        },

        emptyCart({commit}) {
            commit('EMPTY_CART')
        },

        setDetailProduct({commit}, product) {
            commit('SET_PRODUCT', product)
        },

        changeWarehouse({commit}, {item, num}) {
            commit('CHANGE_WAREHOUSE', {item, num})
        }


    },

    mutations: {
        CHANGE_WAREHOUSE (state, {item, num}){
            let index = state.cart.indexOf(item)
            state.cart[index].warehouse = num;
        },

        GET_PRODUCTS (state, products) {
            state.products = products
        },

        SET_PRODUCT (state, product) {
            state.product = product
        },

        ADD_TO_CART (state, {product, quantity, warehouse}) {
            let productInCart = state.cart.find(item => {
                return item.product.id === product.id;
            });

            if(productInCart) {
                productInCart.quantity += quantity;
                return;
            }

            state.cart.push({
                product,
                quantity,
                warehouse
            })
        },

        REMOVE_PRODUCT_FROM_CART (state, item) {
            let index = state.cart.indexOf(item)
            state.cart.splice(index,1)
        },

        // increases item in cart by one
        INCREASE (state, item) {
            let index = state.cart.indexOf(item)
            state.cart[index].quantity++
        },

        // decreases item in cart by one
        DECREASE (state, item) {
            let index = state.cart.indexOf(item)
            if( state.cart[index].quantity === 1) {
                state.cart.splice(index,1)
            } else {
                state.cart[index].quantity--
            }
        },

        setProductById (state,product) {
            state.product = product
        },

        EMPTY_CART(state){
            state.cart = []
        },





    }
}
