package com.bachelortask.warehouseapp.fakedata;

import com.bachelortask.warehouseapp.categories.Book;
import com.bachelortask.warehouseapp.categories.Camera;
import com.bachelortask.warehouseapp.categories.Computer;
import com.bachelortask.warehouseapp.categories.TV;
import com.bachelortask.warehouseapp.category.Category;
import com.github.javafaker.Faker;

import java.util.ArrayList;
import java.util.List;
import java.util.Random;

public class ProductManager {
    private Faker faker;
    private Random random;

    public ProductManager() {
        faker = new Faker();
        random = new Random();
    }

    /**
     * Makes list of computer objects to add to database as test data
     * @param numberOfComputer
     * @return
     */
    public List<Computer> getProductComputer(int numberOfComputer) {
        List<Computer> computers = new ArrayList<>();
        String[] producers = {"Lenovo", "Apple", "Acer", "Samsung", "Dell", "HP"};
        String[] cpuProviders = {"Intel", "AMD", "M1"};
        int[] rams = {2, 4, 8, 16, 32};

        for (int i = 0; i < numberOfComputer; i++) {

            String producer = producers[random.nextInt(producers.length)];
            String model = faker.regexify("[A-Z]{3}-[0-9]{2,3}-[a-zA-Z]{1,3}");

            String cpu = cpuProviders[random.nextInt(cpuProviders.length)]
                    + " - " + faker.regexify("[a-z]{1,2}[0-9]{1,3} processor");
            String ram = rams[random.nextInt(rams.length)] + faker.regexify(" GB-[A-Z]{3} RAM");

            double price = getRandomPrice(5550.0, 3000.0, 1300.0);

            String img = randomComputerImage();

            Category category = new Category(1L, "computers");

            String name = producer + " " + model;
            String desc = "The new " + model + " from " + producer + " with " + cpu + " and " + ram;

            computers.add(new Computer(name, desc, img, price, category, producer, model, cpu, ram));
        }

        return computers;
    }

    /**
     * Makes list of camera objects to add to database as test data
     * @param numberOfCameras
     * @return
     */
    public List<Camera> getProductCamera(int numberOfCameras) {
        List<Camera> cameras = new ArrayList<>();

        String[] producers = {"Canon", "Nikon", "Panasonic", "Samsung", "Sony", "Olympus"};

        int[] zooms = {20, 40, 80, 160, 320};

        for (int i = 0; i < numberOfCameras; i++) {

            String producer = producers[random.nextInt(producers.length)];
            String model = faker.regexify("[A-Z]{3}-[0-9]{2,3}-[a-zA-Z]{1,3}");

            double megapixels = 20 + (100 - 20) * random.nextDouble();
            int zoom = zooms[random.nextInt(zooms.length)];

            //TODO
            String img = randomCameraImage();

            double price = getRandomPrice(2519.0, 1250.0, 300.0);
            Category category = new Category(3L, "cameras");

            String name = producer + " " + model;
            String desc = "The new " + model + " from " + producer + " with " + megapixels + " and " + zoom + "x zoom";

            cameras.add(new Camera(name, desc, img, price, category, producer, model, megapixels, zoom));
        }

        return cameras;
    }

    /**
     * Makes list of tv objects to add to database as test data
     * @param numberOfTVs
     * @return
     */
    public List<TV> getProductTV(int numberOfTVs) {
        List<TV> tvs = new ArrayList<>();

        String[] producers = {"LG", "Hisense", "Panasonic", "Samsung", "Sony", "Luxor"};
        String[] screens = {"Tube", "4K OLED", "4K QLED", "UHD", "LED", "8K OLED", "8K QLED"};

        for (int i = 0; i < numberOfTVs; i++) {

            String producer = producers[random.nextInt(producers.length)];
            String model = faker.regexify("[A-Z]{3}-[0-9]{2,3}");

            String screen = screens[random.nextInt(screens.length)];
            boolean isSmart = true;
            if (screen.equals("Tube") || screen.equals("UHD")) {
                isSmart = false;
            }

            double price = getRandomPrice(6900, 5000.0, 1500.0);
            Category category = new Category(2L, "tvs");
            //TODO change img
            String img = randomTvImage();

            String name = producer + " " + model;
            String desc = "";
            if (isSmart) {
                desc = "The new smart " + screen + ", " + model + " from " + producer;
            } else {
                desc = "The old not so smart " + model + " from " + producer;
            }

            tvs.add(new TV(name, desc, img, price, category, producer, model, screen, isSmart));
        }

        return tvs;
    }

    /**
     * Makes list of book objects to add to database as test data
     * @param numberOfTitles
     * @return
     */
    public List<Book> getProductBook(int numberOfTitles) {
        List<Book> books = new ArrayList<>();

        for (int i = 0; i < numberOfTitles; i++) {

            String name = faker.book().title();
            //double price = faker.number().randomDouble(2,39, 450);
            double price = getRandomPrice(150.0, 50.0, 30.0);
            Category category = new Category(4L, "books");

            String img = randomBookImage();

            String isbn = faker.number().digits(3) + "-" + faker.number().digits(8);
            String author = faker.book().author();
            String publisher = faker.book().publisher();
            int edition = faker.number().numberBetween(1, 9);

            String desc = name + " by author " + author + ", edition: " + edition + " published by " + publisher;

            books.add(new Book(name, desc, img, price, category, isbn, author, publisher, edition));
        }

        return books;
    }

    /**
     * Calculates and returns random price for products.
     * @param mean
     * @param variance
     * @param lowestPrice
     * @return
     */
    private double getRandomPrice(double mean, double variance, double lowestPrice) {
        double price = mean + random.nextGaussian() * variance;
        if (price < lowestPrice) {
            return mean;
        } else {
            return Math.round(price*100)/100.0;
        }
    }

    /**
     * Adds random images to book object.
     * @return
     */
    private String randomBookImage(){
        String[] bookImages = {
                "https://binaries.templates.cdn.office.net/support/templates/en-us/lt22301254_quantized.png",
                "https://i.pinimg.com/236x/0c/ee/7e/0cee7e54fda8ac99ec11459448e89c7d.jpg",
                "https://d1csarkz8obe9u.cloudfront.net/posterpreviews/action-thriller-book-cover-design-template-3675ae3e3ac7ee095fc793ab61b812cc_screen.jpg?ts=1588152105",
                "https://m.media-amazon.com/images/I/41gr3r3FSWL.jpg",
                "https://images-platform.99static.com//uJEtUV24TbkSrTUJDn41n0of0nY=/251x112:1136x998/fit-in/590x590/projects-files/67/6775/677558/2960c98f-1049-40d8-a00d-74d81dc03909.jpg",
                "https://binaries.templates.cdn.office.net/support/templates/en-us/lt66804846_quantized.png",
                "https://img.freepik.com/free-psd/book-cover-mockup_125540-572.jpg?size=626&ext=jpg"
        };

        return bookImages[random.nextInt(bookImages.length)];
    }


    private String randomComputerImage() {
        String[] computerImages = {
                "https://www.getonlineathome.org/media/pc-bundle.png",
                "https://i.dell.com/is/image/DellContent//content/dam/global-site-design/product_images/dell_client_products/desktops/inspiron_desktops/27_7790/general/new-category-page-desktop-inspiron-27-7790-3880-800x620.png?fmt=png-alpha&amp;wid=800&amp;hei=620",
                "https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcQ5C0xQwnu6u6K3-dLSbITJ6jx1TxMGNxAd6A&usqp=CAU"
        };
        return computerImages[random.nextInt(computerImages.length)];
    }

    private String randomCameraImage() {
        String[] cameraImages = {
                "https://www.canon.no/media/eos_range_tcm85-1266213.png",
                "https://media.wired.com/photos/5b64db3717c26f0496f4d62d/125:94/w_1976,h_1486,c_limit/Canon-G7XII-SOURCE-Canon.jpg",
                "https://image.shutterstock.com/image-photo/camera-260nw-610909205.jpg"
        };
        return cameraImages[random.nextInt(cameraImages.length)];
    }

    private String randomTvImage() {
        String[] tvImages = {
                "https://www.netonnet.no/GetFile/ProductImagePrimary/lyd-bilde/tv/28-37/xiaomi-mi-led-tv-4a-32-eu(1012572)_383142_5_Normal_Extra.jpg",
                "https://www.komplett.no/img/p/800/1161430.jpg",
                "https://images.philips.com/is/image/PhilipsConsumer/75PUS7354_12-IMS-no_NO?$jpglarge$&wid=1250"
        };
        return tvImages[random.nextInt(tvImages.length)];
    }
    

} // END OF CLASS

