package com.bachelortask.warehouseapp.order;

import com.bachelortask.warehouseapp.product.Product;
import com.bachelortask.warehouseapp.user.Customer;
import com.bachelortask.warehouseapp.warehouse.Warehouse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
public class OrderController {

    @Autowired
    private OrderService orderService;

    /**
     * Returns all orders from database
     * @return
     */
    @RequestMapping("/orders")
    @CrossOrigin(origins = "http://localhost:8080")
    public List<Orders> getOrders() {
        return orderService.getOrders();
    }

    /**
     * Returns all orders for one customer based on id
     * @param customerId customer id
     * @return
     */
    @RequestMapping("/customers/{customerId}/orders")
    @CrossOrigin(origins = "http://localhost:8080")
    public List<Orders> getOrderByCustomerId(@PathVariable Long customerId) {
        return orderService.getOrderByCustomerId(customerId);
    }

    /**
     * Returns orders by id
     * @param productId id the product
     * @return
     */
    @RequestMapping("/products/{productId}/ordersByProductId")
    @CrossOrigin(origins = "http://localhost:8080")
    public List<Orders> getOrderByProductId(@PathVariable Long productId) {
        return orderService.getOrderByProductId(productId);
    }

    /**
     * For adding order to database based on customer id, product id and warehouse id
     * @param orders object to add persist in database
     * @param customerId
     * @param productId
     * @param warehouseId
     */
    @PostMapping("customers/{customerId}/orders/{productId}/warehouse/{warehouseId}")
    @CrossOrigin(origins = "http://localhost:8080")
    public void confirmOrder(@RequestBody Orders orders,
                             @PathVariable Long customerId,
                             @PathVariable Long productId,
                                @PathVariable Long warehouseId) {
        orders.setCustomer(new Customer(customerId));
        orders.setProduct(new Product(productId));
        orders.setWarehouse(new Warehouse(warehouseId));
        orderService.confirmOrder(orders);
    }
}