package com.bachelortask.warehouseapp.order;

import com.bachelortask.warehouseapp.product.Product;
import com.bachelortask.warehouseapp.user.Customer;
import com.bachelortask.warehouseapp.warehouse.Warehouse;

import javax.persistence.*;

import java.time.LocalDateTime;

import static javax.persistence.GenerationType.SEQUENCE;

@Entity
public class Orders {
    @Id
    @SequenceGenerator(
            name = "orders_sequence",
            sequenceName = "orders_sequence",
            allocationSize = 1
    )
    @GeneratedValue(
            strategy = SEQUENCE,
            generator = "orders_sequence"
    )
    private Long id;

    @Column(
            name = "order_date",
            nullable = false,
            columnDefinition = "TIMESTAMP"
    )
    private LocalDateTime orderDate;

    @ManyToOne
    @JoinColumn(name = "fk_customer")
    private Customer customer;

    @ManyToOne
    @JoinColumn(name = "fk_product")
    private Product product;

    @ManyToOne
    @JoinColumn(name = "fk_warehouse")
    private Warehouse warehouse;

    @Column(nullable = false)
    private int quantity;

    @Column(nullable = false)
    private double totalPrice;

    public Orders() {}

    public Orders(Customer customer) {
        this.customer = customer;
    }

    public Orders(Product product) {
        this.product = product;
    }

    public Orders(LocalDateTime date, Customer customer, Product product) {
        this.orderDate = date;
        this.customer = customer;
        this.product = product;
    }

    public Orders(LocalDateTime orderDate, Customer customer, Product product,
                  Warehouse warehouse, int quantity, double totalPrice) {
        this.orderDate = orderDate;
        this.customer = customer;
        this.product = product;
        this.warehouse = warehouse;
        this.quantity = quantity;
        this.totalPrice = totalPrice;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Orders(LocalDateTime orderDate) {
        this.orderDate = orderDate;
    }

    public LocalDateTime getOrderDate() {
        return orderDate;
    }

    public void setOrderDate(LocalDateTime orderDate) {
        this.orderDate = orderDate;
    }

    public Product getProduct() {
        return product;
    }

    public void setProduct(Product product) {
        this.product = product;
    }

    public Customer getCustomer() {
        return customer;
    }

    public void setCustomer(Customer customer) {
        this.customer = customer;
    }

    public Warehouse getWarehouse() {
        return warehouse;
    }

    public void setWarehouse(Warehouse warehouse) {
        this.warehouse = warehouse;
    }

    public int getQuantity() {
        return quantity;
    }

    public void setQuantity(int quantity) {
        this.quantity = quantity;
    }

    public double getTotalPrice() {
        return totalPrice;
    }

    public void setTotalPrice(double totalPrice) {
        this.totalPrice = totalPrice;
    }
}
