package com.bachelortask.warehouseapp.product;

import com.bachelortask.warehouseapp.category.Category;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
public class ProductController {

    @Autowired
    private ProductService productService;

    /**
     * Returns all products from database
     * @return
     */
    @RequestMapping("/products")
    @CrossOrigin(origins = "http://localhost:8080")
    public List<Product> getProducts() {
        return productService.getProducts();
    }

    /**
     * Returns all products based on category id from database
     * @param categoryId
     * @return
     */
    @RequestMapping("/products/{categoryId}")
    @CrossOrigin(origins = "http://localhost:8080")
    public List<Product> getProductsByCategory(@PathVariable Long categoryId) {
        return productService.getProductsByCategory(categoryId);
    }

    /**
     * Returns product based on its id
     * @param id
     * @return
     */
    @RequestMapping("/product/{productId}")
    @CrossOrigin(origins = "http://localhost:8080")
    public Product getProductById(@RequestParam Long id){
        return productService.getProductById(id);
    }



    /**
     * Returns list of all product ids in warehouse database
     * @return
     */
    @RequestMapping("/getProductIds")
    @CrossOrigin(origins = "http://localhost:8080")
    public List<Long> getProductsIdList() {
        return productService.getProductsIdList();
    }

    /**
     * Returns list of product based on query string
     * @param query
     * @return
     */
    @RequestMapping("/search/{query}")
    @CrossOrigin(origins = "http://localhost:8080")
    public List<Product> getProductsBySearchString(@PathVariable String query) {
        return productService.getProductsBySearchString(query);
    }

    /**
     * Adds product object to database
     * @param product
     * @param categoryId
     */
    @PostMapping("/products/{categoryId}/add")
    @CrossOrigin(origins = "http://localhost:8080")
    public void addProduct(@RequestBody Product product, @PathVariable Long categoryId) {
        product.setCategory(new Category(categoryId, ""));
        productService.addProduct(product, categoryId);
    }

    /**
     * Add list of product to database
     * @param products
     * @param categoryId
     */
    @PostMapping("/products/{categoryId}/addMany")
    @CrossOrigin(origins = "http://localhost:8080")
    public void addManyProducts(@RequestBody List<Product> products, @PathVariable Long categoryId) {
        //products.setCategory(new Category(categoryId, ""));
        productService.addManyProducts(products, categoryId);
    }

    /**
     * Removes product from database based on its id
     * @param productId
     */
    @DeleteMapping("/products/{productId}/remove")
    @CrossOrigin(origins = "http://localhost:8080")
    public void removeProduct(@PathVariable Long productId) {
        productService.removeProduct(productId);
    }

}
