package com.bachelortask.warehouseapp.product;

import com.bachelortask.warehouseapp.category.Category;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class ProductService {
    @Autowired
    private ProductRepository productRepository;

    /**
     * Gets list of product from database
     * @return
     */
    public List<Product> getProducts() {
        List<Product> products = new ArrayList<>();
        productRepository.findAll().forEach(products::add);
        return products;
    }

    /**
     * Gets list of products from database based on category id
     * @param product
     * @param categoryId
     */
    public void addProduct(Product product, Long categoryId) {
        productRepository.save(product);
    }

    /**
     * Deletes product from database based on its id
     * @param productId
     */
    public void removeProduct(Long productId) {
        productRepository.deleteById(productId);
    }

    /**
     * Get all ids from warehouse database
     * @return
     */
    public List<Long> getProductsIdList() {
        List<Product> products = new ArrayList<>();
        productRepository.findAll().forEach(products::add);
        List<Long> ids = new ArrayList<>();
        for (Product p : products) {
            ids.add(p.getId());
        }
        return ids;
    }

    /**
     * Gets list of all product from database. Returns list of product with matching string
     * from the query string in parameter.
     * @param query
     * @return
     */
    public List<Product> getProductsBySearchString(String query) {
        List<Product> products = productRepository.findAll();
        List<Product> productList = new ArrayList<>();

        for (Product p : products) {
            String n = p.getName().toLowerCase();
            String desc = p.getDescription().toLowerCase();
            query = query.toLowerCase();
            if (n.contains(query) || desc.contains(query)) {
                productList.add(p);
            }
        }
        return productList;
    }

    /**
     * Adds ist of products to database
     * @param products
     * @param categoryId
     */
    public void addManyProducts(List<Product> products, Long categoryId) {
        for (Product p : products) {
            p.setCategory(new Category(categoryId));
            productRepository.save(p);
        }
    }

    /**
     * Returns products by category id
     * @param categoryId
     * @return
     */
    public List<Product> getProductsByCategory(Long categoryId) {
        return productRepository.getProductsByCategory(categoryId);
    }

    /**
     * Gets product from database based on its id
     * @param productId
     * @return
     */
    public Product getProductById(Long productId) {
       return productRepository.getProductsById(productId);
    }
}