package com.bachelortask.warehouseapp.user;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.crypto.bcrypt.BCryptPasswordEncoder;
import org.springframework.security.crypto.password.PasswordEncoder;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;

@Service
public class CustomerService {

    @Autowired
    private CustomerRepository customerRepository;

    private PasswordEncoder passwordEncoder = new BCryptPasswordEncoder();

    /**
     * Gets list of customers from database
     * @return
     */
    public List<Customer> getCustomer() {
        return customerRepository.findAll();
    }

    /**
    public void addManyUsers(List<Customer> users) {
        for (Customer c : users) {
            customerRepository.save(c);
        }
    }
     */

    /**
     * Returns customer based on its id
     * @param customerId
     * @return
     */
    public Optional<Customer> getCustomerById(Long customerId) {
        return customerRepository.findById(customerId);
    }

    /**
     * Add customer object to database where password is encoded
     * @param user
     */
    public void addUser(Customer user) {
        String encodedPassword = this.passwordEncoder.encode(user.getPassword());
        user.setPassword(encodedPassword);
        customerRepository.save(user);
    }

    /**
     * Returns customer if password checks out.
     * @param email
     * @param password
     * @return
     */
    public Optional<Customer> login(String email, String password) {
        Optional<Customer> user = Optional.ofNullable(customerRepository.findCustomerByEmail(email));
        if(this.passwordEncoder.matches(password, user.get().getPassword())){
            return user;
        } else if(user.get().getPassword().equals(password)) {
            return user;
        } else  {
            return null;
        }
    }
}
